RIOT PAL (RIOT Protocol Abstraction Layer)
================================

Introduction
------------

A set of python modules that abstract away and standardize shell based commands in RIOT and for bare metal memory map access.
